@@ -8,8 +8,8 @@ https://www.aug.ipp.mpg.de/~git/pyaug/sfread.html
 
 """
 __author__  = 'Giovanni Tardini (Tel. 1898)'
-__version__ = '0.2.1'
-__date__    = '30.09.2021'
+__version__ = '0.2.2'
+__date__    = '06.10.2021'
 
 import sys
 
@@ -17,6 +17,8 @@ from .sfread import *
 from .sf2equ import *
 from .libddc import ddcshotnr, previousshot
 from .mapeq import *
+from .ww import *
+from .sfh import *
 
 # Backward compatibility.
 
