@@ -1,23 +1,13 @@
 import os, datetime
 from struct import unpack
 import numpy as np
-try:
-    from . import sfdics, sfhread, sfobj, manage_ed, parse_kwargs
-except:
-    import sfdics, sfhread, sfobj, manage_ed, parse_kwargs
+
+from . import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt
 
 verbose = True
 verbose = False
 PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
-def to_str(str_or_byt):
-    """
-    Converts a plain string to a byte string (python3 compatibility)
-    """
-
-    str_out = str_or_byt.decode('utf8') if isinstance(str_or_byt, bytes) else str_or_byt
-    return str_out.strip()
-
 
 def parse_url(url, blen=100):
     """
@@ -76,7 +66,7 @@ def getlastshot():
         if page is None:
             return None
         else:
-            page = to_str(page)
+            page = str_byt.to_str(page)
             idx = page.find("Current shot:")
             if idx < 0:
                 print('Missing substring "Current shot:" in %s, exiting' %url2)
@@ -86,7 +76,7 @@ def getlastshot():
             b = substr.find('<', a)
             nshot = int(substr[a:b])-1
     else:
-        sshot = to_str(bshot)
+        sshot = str_byt.to_str(bshot)
         try:
             nshot = int(sshot)
         except:
@@ -142,7 +132,7 @@ def get_gc(nshot=30136):
             comp_z[jcom] = zzgc[inxbeg[jcom]:inxbeg[jcom+1]]
     else:
         for jcom, lbl in enumerate(gcnames):
-            lbl = to_str(lbl)
+            lbl = str_byt.to_str(lbl)
             if flag_use[jcom] > 0:
                 comp_r[lbl] = rrgc[inxbeg[jcom]:inxbeg[jcom+1]]
                 comp_z[lbl] = zzgc[inxbeg[jcom]:inxbeg[jcom+1]]
@@ -208,8 +198,8 @@ class SFREAD:
                     self.sfh = sfhread.read_sfh(byt_str)
         self.status = hasattr(self, 'sfh')
         if self.status:
-            self.objects = [ i for i in self.sfh['obj_nam'] if self.sfh[i].obj_type in [6, 7, 8, 13] ]
-            self.parsets = [ i for i in self.sfh['obj_nam'] if self.sfh[i].obj_type in [3, 4] ]
+            self.objects = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [6, 7, 8, 13] ]
+            self.parsets = [ lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type in [3, 4] ]
         self.cache = {}
 
 
@@ -244,7 +234,7 @@ class SFREAD:
         Reads the timebase of a given SIG, SGR or AB
         """
 
-        obj = to_str(obj)
+        obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp == 8:
@@ -262,7 +252,7 @@ class SFREAD:
         Reads the areabase of a given SIG or SGR
         """
 
-        obj = to_str(obj)
+        obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp == 13:
@@ -280,7 +270,7 @@ class SFREAD:
         Reads the data of a given TB, AB, SIG or SGR
         """
 
-        obj = to_str(obj)
+        obj = str_byt.to_str(obj)
         data = None
         if obj not in self.sfh.keys():
             return None
@@ -401,10 +391,10 @@ class SFREAD:
         """
         Returns coefficients for signal(group) calibration
         """
-        obj = to_str(obj)
+        obj = str_byt.to_str(obj)
         for rel in self.get_rel_names(obj):
             if self.sfh[rel].obj_type == 4:
-                caltyp = to_str(sfdics.cal_type[self.sfh[rel].cal_type])
+                caltyp = str_byt.to_str(sfdics.cal_type[self.sfh[rel].cal_type])
                 if caltyp == 'LinCalib':
                     print('PSet for calib: %s' %rel)
                     return self.getparset(rel)
@@ -416,7 +406,7 @@ class SFREAD:
         Returns data and metadata of a Parameter Set
         """
 
-        pset = to_str(pset)
+        pset = str_byt.to_str(pset)
         sfo = self.sfh[pset]
         otyp = sfo.obj_type
         if otyp not in (3, 4):
@@ -427,7 +417,7 @@ class SFREAD:
         j0 = 0
         sfo.par_d = {}
         for j in range(sfo.items):
-            pname = to_str(buf[j0: j0+8])
+            pname = str_byt.to_str(buf[j0: j0+8])
             unit, dfmt, n_items = unpack('>3H', buf[j0+8:  j0+14])
             if verbose:
                 print(pname, unit, dfmt, n_items)
@@ -466,7 +456,7 @@ class SFREAD:
         if obj is None:
             obj = 'SIGNALS'
         else:
-            obj = to_str(obj)
+            obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         dfmt = sfo.data_format
@@ -479,6 +469,11 @@ class SFREAD:
         return [self.get_obj_name(jid) for jid in list_ids]
 
 
+    def getlist_by_type(self, obj_type=7):
+
+        return [lbl for lbl in self.sfh['obj_nam'] if self.sfh[lbl].obj_type == obj_type]
+
+
     def get_obj_name(self, jobj):
         """
         Returns the object name for an inpur object ID
@@ -492,7 +487,7 @@ class SFREAD:
         Returns the object ID for a given objeect
         """
 
-        lbl = to_str(lbl)
+        lbl = str_byt.to_str(lbl)
         return self.sfh['obj_id'][lbl]
 
 
@@ -501,7 +496,7 @@ class SFREAD:
         Returns the relation names of a given object
         """
 
-        lbl = to_str(lbl)
+        lbl = str_byt.to_str(lbl)
         rels_id = self.sfh[lbl].rel
         return [self.get_obj_name(jobj) for jobj in rels_id if jobj < 65535]
 
@@ -538,7 +533,7 @@ class SFREAD:
         by comparing with the size of the related TBase
         """
 
-        obj = to_str(obj)
+        obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp != 6:
@@ -563,7 +558,7 @@ class SFREAD:
         by comparing with the size of the related TBase
         """
 
-        obj = to_str(obj)
+        obj = str_byt.to_str(obj)
         sfo = self.sfh[obj]
         otyp = sfo.obj_type
         if otyp != 6:
